import { useFetchDeparture } from "./useFetchDeparture";
import { fetchZones } from "../Api";
import { initDB, addData, deleteData, getStoreData, updateData } from '../db';
import { act, render, renderHook, screen, waitFor } from "@testing-library/react";
import { MemoryRouter } from "react-router-dom";
import '@testing-library/jest-dom';

jest.mock("../Api");
jest.mock('../db');

const mockedFetchZones = fetchZones as jest.MockedFunction<typeof fetchZones>;
const mockedInitDB = initDB as jest.MockedFunction<typeof initDB>;
const mockedAddData = addData as jest.MockedFunction<typeof addData>;
const mockedDeleteData = deleteData as jest.MockedFunction<typeof deleteData>;
const mockedGetStoreData = getStoreData as jest.MockedFunction<typeof getStoreData>;
const mockedUpdateData = updateData as jest.MockedFunction<typeof updateData>;

const mockFlights = [
    {
        id: 1,
        flight_code: "ABC123",
        origin: "City A",
        destination: "City X",
        departure_time: "2023-10-30 10:00 AM",
        arrival_time: "2023-10-30 12:00 PM",
        gate: "A1",
        status: "On Time"
    },
    {
        id: 2,
        flight_code: "XYZ789",
        origin: "City B",
        destination: "City Y",
        departure_time: "2023-10-31 01:30 PM",
        arrival_time: "2023-10-31 02:30 PM",
        gate: "B2",
        status: "Delayed"
    },
];


describe("useFetchDeparture Hook Tests", () => {
    beforeEach(() => {
        jest.clearAllMocks();
        localStorage.clear();
    });

    test("Fetches data initially and updates zones state", async () => {
        mockedFetchZones.mockResolvedValueOnce(mockFlights);
        mockedInitDB.mockResolvedValueOnce(false);
        mockedGetStoreData.mockResolvedValueOnce([]);
        mockedAddData.mockImplementationOnce((store, data) => Promise.resolve(data));

        const { result } = renderHook(() => useFetchDeparture("origin"));

        await waitFor(() => {

            expect(result.current.zones).toEqual(mockFlights);
            expect(mockedFetchZones).toHaveBeenCalledWith("origin", undefined, null);
            expect(mockedInitDB).toHaveBeenCalledTimes(1);
            expect(mockedAddData).toHaveBeenCalledWith("departure", mockFlights[0]);
        });
    });

    // test("Handles errors during initial data fetch", async () => {
    //     const errorMessage = "Error fetching data";
    //     mockedInitDB.mockResolvedValueOnce(false);
    //     mockedGetStoreData.mockResolvedValueOnce([]);
    //     mockedFetchZones.mockRejectedValueOnce(new Error(errorMessage));

    //     const { result } = renderHook(() => useFetchDeparture("destination"));

    //     await waitFor(() => {

    //         expect(result.current.zones).toEqual([]);
    //         expect(result.current.error).toEqual(errorMessage);
    //         expect(mockedFetchZones).toHaveBeenCalledWith(undefined, "destination", null);
    //     })
    // });
});
